#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-2s8rQV9irz21pyc5cIsIV0
key:                  ghcide-2.3.0.0-2s8rQV9irz21pyc5cIsIV0
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  b6af35187a92df1216b8271b502a487e
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-2s8rQV9irz21pyc5cIsIV0
depends:
    Diff-1.0-n0RmXNQVFrGyP2VCRbod4 Glob-0.10.2-73zp6DP8O307OuiQUadSOH
    aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG array-0.5.6.0
    async-2.2.6-ITRC11Ox8a3Q3zDt3UwKf base-4.18.2.1
    base16-bytestring-1.0.2.0-JUk8AN14DnGL6jo9gy2A1N binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-42CJmR7jfDI1QxR1AA3Hru
    co-log-core-0.3.2.7-8DwTpSJG0WR4WGLDokvZMp containers-0.6.7
    cryptohash-sha1-0.11.101.0-FicrQGbdqQGEupCfHibC0e
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG deepseq-1.4.8.1
    dependent-map-0.4.0.1-EcvwCsFRlXhK6A8Ss4O7Fy
    dependent-sum-0.7.2.0-5KVStjcgoBTD7ZsXrC0AkO directory-1.3.8.5
    dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp
    enummapset-0.7.3.0-IFw2hF6YS1c3pxWWuxSN1m exceptions-0.10.7
    extra-1.7.16-JQjr8PVpkEB4amK6gdUMOF filepath-1.4.300.1
    fingertree-0.1.6.3-GIrjDkIwow6LTi6FTewdnC
    focus-1.0.3.2-GvHulYJKvb0IU5E5h6uwlC ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-F9K4LQtfbaoJ9Y6Vto34ZR
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-9nbL2ZBskuQHfKdvegoLtI
    hashable-1.4.7.0-Ws19qMM2f99bApawlWBTg
    hie-bios-0.12.0-LJvwJudLvBuLpaSm4UzpLl
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-KU0J8Xnn0al9iJMF7TDNCh
    hls-graph-2.3.0.0-72RWBHkz19LC8RLM7o3sC0
    hls-plugin-api-2.3.0.0-JWlMOnERUdN8af70lHp5qp
    implicit-hie-0.1.4.0-EkhMDXHIgol7D9IDJd06zX
    implicit-hie-cradle-0.5.0.1-FRw2bYS58r3LtjwQKDeB5g
    lens-5.3.5-KA5gcUGZYMJ4Yj2DW4uyDf
    list-t-1.0.5.7-BaBWhkGn3O29fyLtbSodkl
    lsp-2.2.0.0-AApQc3pMEos5GLRJ0i2B8c
    lsp-types-2.0.2.0-4NXabkuUeFJ9jCQLmB6g4 mtl-2.3.1
    opentelemetry-0.8.0-KPGpvT7FT4H8kLa7E2WSM4
    optparse-applicative-0.18.1.0-47hFtTaenhPJTeGKwQSLW6
    parallel-3.3.0.0-777lW8EKp7RLYem9SqDKwn
    prettyprinter-1.7.2-1DGqCnBpxP9HlPCcGuqpc1
    prettyprinter-ansi-terminal-1.1.4-JHkdh8ZQnpYA1tQeTHAtKh
    random-1.2.1.3-2fto0SX8B0n5d0nC1pFLHo
    regex-tdfa-1.3.2.5-7A9AvRIGkk4HgHOwz4zjio
    row-types-1.0.1.2-DPodS6wEnzgipmVs1yqhU
    safe-exceptions-0.1.7.4-KsLBtnEzfQ1Kg6OJ9Y9PUU
    sorted-list-0.2.3.1-HWlvtQShLGJE6VWzHzO4ni
    sqlite-simple-0.4.19.0-4Qmfk9YKC8OjwWkN2Ke3z stm-2.5.1.0
    stm-containers-1.2.2-4WGXD0PijvqKy4hKRUmpAn
    syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE text-2.0.2
    text-rope-0.3-Ei55WDCsuAqIC7ggXqwhlE time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-7sR1Ziz3z9kDMr2BTZq7dj
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP
    vector-0.13.2.0-KNP2q6eDEp8AmnRr9wgHHB

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

